@@ -3,30 +3,19 @@
 #' Create a file upload control that can be used to upload one or more files.
 #'
 #' Whenever a file upload completes, the corresponding input variable is set
-#' to a dataframe. This dataframe contains one row for each selected file, and
-#' the following columns:
-#' \describe{
-#'   \item{\code{name}}{The filename provided by the web browser. This is
-#'   \strong{not} the path to read to get at the actual data that was uploaded
-#'   (see
-#'   \code{datapath} column).}
-#'   \item{\code{size}}{The size of the uploaded data, in
-#'   bytes.}
-#'   \item{\code{type}}{The MIME type reported by the browser (for example,
-#'   \code{text/plain}), or empty string if the browser didn't know.}
-#'   \item{\code{datapath}}{The path to a temp file that contains the data that was
-#'   uploaded. This file may be deleted if the user performs another upload
-#'   operation.}
-#' }
+#' to a dataframe. See the `Server value` section.
 #'
 #' @family input elements
 #'
 #' @inheritParams textInput
 #' @param multiple Whether the user should be allowed to select and upload
-#'   multiple files at once. \bold{Does not work on older browsers, including
-#'   Internet Explorer 9 and earlier.}
+#'   multiple files at once. **Does not work on older browsers, including
+#'   Internet Explorer 9 and earlier.**
 #' @param accept A character vector of MIME types; gives the browser a hint of
 #'   what kind of files the server is expecting.
+#' @param buttonLabel The label used on the button. Can be text or an HTML tag
+#'   object.
+#' @param placeholder The text to show before a file has been uploaded.
 #'
 #' @examples
 #' ## Only run examples in interactive R sessions
@@ -68,9 +57,26 @@
 #'
 #' shinyApp(ui, server)
 #' }
+#'
+#' @section Server value:
+#' A `data.frame` that contains one row for each selected file, and following columns:
+#' \describe{
+#'   \item{`name`}{The filename provided by the web browser. This is
+#'   **not** the path to read to get at the actual data that was uploaded
+#'   (see
+#'   `datapath` column).}
+#'   \item{`size`}{The size of the uploaded data, in
+#'   bytes.}
+#'   \item{`type`}{The MIME type reported by the browser (for example,
+#'   `text/plain`), or empty string if the browser didn't know.}
+#'   \item{`datapath`}{The path to a temp file that contains the data that was
+#'   uploaded. This file may be deleted if the user performs another upload
+#'   operation.}
+#' }
+#'
 #' @export
 fileInput <- function(inputId, label, multiple = FALSE, accept = NULL,
-  width = NULL) {
+  width = NULL, buttonLabel = "Browse...", placeholder = "No file selected") {
 
   restoredValue <- restoreInput(id = inputId, default = NULL)
 
@@ -100,17 +106,17 @@ fileInput <- function(inputId, label, multiple = FALSE, accept = NULL,
 
   div(class = "form-group shiny-input-container",
     style = if (!is.null(width)) paste0("width: ", validateCssUnit(width), ";"),
-    label %AND% tags$label(label),
+    shinyInputLabel(inputId, label),
 
     div(class = "input-group",
       tags$label(class = "input-group-btn",
         span(class = "btn btn-default btn-file",
-          "Browse...",
+          buttonLabel,
           inputTag
         )
       ),
       tags$input(type = "text", class = "form-control",
-        placeholder = "No file selected", readonly = "readonly"
+        placeholder = placeholder, readonly = "readonly"
       )
     ),
 
